% This function generates a random set of change points for both the
% well-log and d18O data sets.  These 'random' change points are used in
% conjunction with the distance measure for comparison purposes in Sections
% 6.1 and 6.2.  The idea is to give context for the magnitude of the
% divergence between the exact and approximate posterior distributions

[N, m] =size(X);             % N = total # data points (N), m = # regressors
d_min = 10;
k_max = 25;
num_samp = 50000;    %parameters(6);


% Variables used in sampling procedure:
samp_holder=zeros(num_samp,k_max);  % Contains each of the num_samp change point solutions

for i=1:num_samp
    %******** (3c)[i] Sample a Number of Change Points ***********************
    num_chgpts = pick_k1(k)-1;  % Since we allow for 0 changepoints, function returns the index of the 'k' vector, 
                                % which is offset from the number of change points by 1 
    if(num_chgpts>0)
        good = 0;
        while(~good)
            chgpts = floor(N*rand(num_chgpts,1));       % Generates a random set of change points
            chgpts = sort(chgpts);
            if ( min(chgpts(2:num_chgpts) - chgpts(1:num_chgpts-1)) >= d_min )
                good = 1;       % Checks to see that none of the change points are too close to each other
            end
        end
        samp_holder(i,1:num_chgpts) = chgpts';
    end
        
    
end

